window.Gleam.initSearch([{"doc":"sheen","title":"sheen","content":"# Sheen\n\n[![Package Version](https://img.shields.io/hexpm/v/sheen)](https://hex.pm/packages/sheen)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sheen/)\n\n```sh\ngleam add sheen\n```\n\nSheen is a library for creating command line argument parsers. It has a convenient and type safe API.\n\n```gleam\nimport argv\nimport sheen\nimport sheen/flag\nimport sheen/arg\nimport sheen/named\n\ntype Mode {\n  Sum\n  Product\n}\n\ntype Args {\n  Args(verbosity: Int, numbers: List(Int), mode: Mode)\n}\n\nfn parser() -&gt; sheen.Parser(Args) {\n  // You are asserting that you&#39;ve built the parser correctly\n  // Otherwise you will receive informative errors\n  let assert Ok(parser) =\n    sheen.new()\n    |&gt; sheen.name(&quot;Number cruncher&quot;)\n    |&gt; sheen.version(&quot;0.1.0&quot;)\n    |&gt; sheen.authors([&quot;Ellie&quot;])\n    |&gt; sheen.build({\n      use verbosity &lt;-\n        flag.new(&quot;verbose&quot;)\n        |&gt; flag.count()\n\n      use mode &lt;-\n        named.new(&quot;mode&quot;)\n        |&gt; named.enum([#(&quot;sum&quot;, Sum), #(&quot;product&quot;, Product)])\n        |&gt; named.required()\n\n      use numbers &lt;-\n        arg.new()\n        |&gt; arg.integer()\n        |&gt; arg.repeated()\n\n      sheen.return({\n        use verbosity &lt;- verbosity\n        use numbers &lt;- numbers\n        use mode &lt;- mode\n        sheen.valid(Args(verbosity, numbers, mode))\n      })\n    })\n  parser\n}\n\npub fn main() {\n  let parse_result =\n    parser()\n    |&gt; sheen.run(argv.load().arguments)\n  case parse_result {\n    Ok(args) -&gt; {\n      // Run you program with the parsed arguments\n      todo\n    }\n    Error(errors) -&gt; {\n      // Sheen collects all errors and returns them as a list\n      // Later I will add a way to pretty print them, and then\n      // show usage information\n      todo\n    }\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/sheen&gt;.\n","url":"index.html"},{"doc":"sheen/error","title":"BuildError","content":"pub type BuildError =\n  String\n\n\nSynonyms:\nsheen/error.BuildError\nsheen/error BuildError","url":"sheen/error.html#BuildError"},{"doc":"sheen/error","title":"BuildResult","content":"pub type BuildResult(a) =\n  Result(a, BuildError)\n\n\nSynonyms:\nsheen/error.BuildResult\nsheen/error BuildResult","url":"sheen/error.html#BuildResult"},{"doc":"sheen/error","title":"ExtractionError","content":"pub type ExtractionError {\n  UnrecognisedLong(String)\n  UnrecognisedShort(String)\n  UnexpectedArgument(String)\n  NoArgument(String)\n  NotAFlag(String)\n}\n\nUnrecognisedLong(String)\n When a long option is not recognised.\n\nUnrecognisedShort(String)\n When a short option is not recognised.\n\nUnexpectedArgument(String)\n When too many arguments are given.\n\nNoArgument(String)\n When a named argument option is not given an argument.\n\nNotAFlag(String)\n When a flag is given an argument.\n\nSynonyms:\nsheen/error.ExtractionError\nsheen/error ExtractionError","url":"sheen/error.html#ExtractionError"},{"doc":"sheen/error","title":"ParseError","content":"pub type ParseError {\n  DecodeError(dynamic.DecodeError)\n  ValidationError(String)\n  ExtractionError(ExtractionError)\n  InternalError(String)\n}\n\nDecodeError(dynamic.DecodeError)\n\n\nValidationError(String)\n\n\nExtractionError(ExtractionError)\n\n\nInternalError(String)\n\n\nSynonyms:\nsheen/error.ParseError\nsheen/error ParseError","url":"sheen/error.html#ParseError"},{"doc":"sheen/error","title":"ParseResult","content":"pub type ParseResult(a) =\n  Result(a, ParseError)\n\n\nSynonyms:\nsheen/error.ParseResult\nsheen/error ParseResult","url":"sheen/error.html#ParseResult"},{"doc":"sheen/error","title":"sheen/error","content":"","url":"sheen/error.html"},{"doc":"sheen","title":"Command","content":"pub type Command(a) =\n  cb.Command(a)\n\n\nSynonyms:\nsheen.Command\nsheen Command","url":"sheen.html#Command"},{"doc":"sheen","title":"ParseResult","content":"pub type ParseResult(a) =\n  Result(a, List(ParseError))\n\n\nSynonyms:\nsheen.ParseResult\nsheen ParseResult","url":"sheen.html#ParseResult"},{"doc":"sheen","title":"Parser","content":"pub type Parser(a) {\n  Parser(\n    spec: ParserSpec,\n    encoders: endec.Encoders,\n    decoder: endec.Decoder(a),\n  )\n}\n\nParser(\n  spec: ParserSpec,\n  encoders: endec.Encoders,\n  decoder: endec.Decoder(a),\n)\n\n\nSynonyms:\nsheen.Parser\nsheen Parser","url":"sheen.html#Parser"},{"doc":"sheen","title":"ParserSpec","content":"pub type ParserSpec {\n  ParserSpec(\n    cmd: cb.CommandSpec,\n    name: option.Option(String),\n    authors: List(String),\n    version: option.Option(String),\n  )\n}\n\nParserSpec(\n  cmd: cb.CommandSpec,\n  name: option.Option(String),\n  authors: List(String),\n  version: option.Option(String),\n)\n\n\nSynonyms:\nsheen.ParserSpec\nsheen ParserSpec","url":"sheen.html#ParserSpec"},{"doc":"sheen","title":"authors","content":"pub fn authors(\n  to parser: ParserSpec,\n  set authors: List(String),\n) -&gt; ParserSpec\n\nSynonyms:\nsheen.authors\nsheen authors","url":"sheen.html#authors"},{"doc":"sheen","title":"build","content":"pub fn build(\n  from parser: ParserSpec,\n  with command: fn(Builder(Nil)) -&gt; Result(Builder(a), String),\n) -&gt; Result(Parser(a), String)\n\nSynonyms:\nsheen.build\nsheen build","url":"sheen.html#build"},{"doc":"sheen","title":"describe","content":"pub fn describe(\n  description: String,\n  cont: fn(Builder(Nil)) -&gt; Result(Builder(a), String),\n) -&gt; fn(Builder(Nil)) -&gt; Result(Builder(a), String)\n\nSynonyms:\nsheen.describe\nsheen describe","url":"sheen.html#describe"},{"doc":"sheen","title":"name","content":"pub fn name(\n  to parser: ParserSpec,\n  set name: String,\n) -&gt; ParserSpec\n\nSynonyms:\nsheen.name\nsheen name","url":"sheen.html#name"},{"doc":"sheen","title":"new","content":"pub fn new() -&gt; ParserSpec\n\nSynonyms:\nsheen.new\nsheen new","url":"sheen.html#new"},{"doc":"sheen","title":"return","content":"pub fn return(\n  decoder: Decoder(a),\n) -&gt; fn(Builder(Nil)) -&gt; Result(Builder(a), String)\n\nSynonyms:\nsheen.return\nsheen return","url":"sheen.html#return"},{"doc":"sheen","title":"run","content":"pub fn run(\n  parser: Parser(a),\n  args: List(String),\n) -&gt; Result(a, List(ParseError))\n\nSynonyms:\nsheen.run\nsheen run","url":"sheen.html#run"},{"doc":"sheen","title":"valid","content":"pub fn valid(value: a) -&gt; Decoder(a)\n\nSynonyms:\nsheen.valid\nsheen valid","url":"sheen.html#valid"},{"doc":"sheen","title":"version","content":"pub fn version(\n  to parser: ParserSpec,\n  set version: String,\n) -&gt; ParserSpec\n\nSynonyms:\nsheen.version\nsheen version","url":"sheen.html#version"},{"doc":"sheen","title":"sheen","content":"","url":"sheen.html"},{"doc":"sheen/arg","title":"Builder","content":"pub opaque type Builder(a)\n\n\nSynonyms:\nsheen/arg.Builder\nsheen/arg Builder","url":"sheen/arg.html#Builder"},{"doc":"sheen/arg","title":"display","content":"pub fn display(\n  builder: Builder(a),\n  display: String,\n) -&gt; Builder(a)\n\nSynonyms:\nsheen/arg.display\nsheen/arg display","url":"sheen/arg.html#display"},{"doc":"sheen/arg","title":"enum","content":"pub fn enum(\n  builder: Builder(String),\n  values: List(#(String, a)),\n) -&gt; Builder(a)\n\nSynonyms:\nsheen/arg.enum\nsheen/arg enum","url":"sheen/arg.html#enum"},{"doc":"sheen/arg","title":"help","content":"pub fn help(builder: Builder(a), help: String) -&gt; Builder(a)\n\nSynonyms:\nsheen/arg.help\nsheen/arg help","url":"sheen/arg.html#help"},{"doc":"sheen/arg","title":"integer","content":"pub fn integer(builder: Builder(String)) -&gt; Builder(Int)\n\nSynonyms:\nsheen/arg.integer\nsheen/arg integer","url":"sheen/arg.html#integer"},{"doc":"sheen/arg","title":"new","content":"pub fn new() -&gt; Builder(String)\n\nSynonyms:\nsheen/arg.new\nsheen/arg new","url":"sheen/arg.html#new"},{"doc":"sheen/arg","title":"optional","content":"pub fn optional(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(Option(a)) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/arg.optional\nsheen/arg optional","url":"sheen/arg.html#optional"},{"doc":"sheen/arg","title":"repeated","content":"pub fn repeated(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(List(a)) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/arg.repeated\nsheen/arg repeated","url":"sheen/arg.html#repeated"},{"doc":"sheen/arg","title":"required","content":"pub fn required(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(a) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/arg.required\nsheen/arg required","url":"sheen/arg.html#required"},{"doc":"sheen/arg","title":"sheen/arg","content":"","url":"sheen/arg.html"},{"doc":"sheen/flag","title":"Builder","content":"pub opaque type Builder\n\n\nSynonyms:\nsheen/flag.Builder\nsheen/flag Builder","url":"sheen/flag.html#Builder"},{"doc":"sheen/flag","title":"boolean","content":"pub fn boolean(\n  builder: Builder,\n) -&gt; fn(\n  fn(fn(fn(Bool) -&gt; Decoder(a)) -&gt; Decoder(a)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(a), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(a), String)\n\nSynonyms:\nsheen/flag.boolean\nsheen/flag boolean","url":"sheen/flag.html#boolean"},{"doc":"sheen/flag","title":"count","content":"pub fn count(\n  builder: Builder,\n) -&gt; fn(\n  fn(fn(fn(Int) -&gt; Decoder(a)) -&gt; Decoder(a)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(a), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(a), String)\n\nSynonyms:\nsheen/flag.count\nsheen/flag count","url":"sheen/flag.html#count"},{"doc":"sheen/flag","title":"display","content":"pub fn display(builder: Builder, display: String) -&gt; Builder\n\nSynonyms:\nsheen/flag.display\nsheen/flag display","url":"sheen/flag.html#display"},{"doc":"sheen/flag","title":"help","content":"pub fn help(builder: Builder, help: String) -&gt; Builder\n\nSynonyms:\nsheen/flag.help\nsheen/flag help","url":"sheen/flag.html#help"},{"doc":"sheen/flag","title":"long","content":"pub fn long(builder: Builder, long: String) -&gt; Builder\n\nSynonyms:\nsheen/flag.long\nsheen/flag long","url":"sheen/flag.html#long"},{"doc":"sheen/flag","title":"new","content":"pub fn new(name: String) -&gt; Builder\n\nSynonyms:\nsheen/flag.new\nsheen/flag new","url":"sheen/flag.html#new"},{"doc":"sheen/flag","title":"short","content":"pub fn short(builder: Builder, short: String) -&gt; Builder\n\nSynonyms:\nsheen/flag.short\nsheen/flag short","url":"sheen/flag.html#short"},{"doc":"sheen/flag","title":"sheen/flag","content":"","url":"sheen/flag.html"},{"doc":"sheen/named","title":"Builder","content":"pub opaque type Builder(a)\n\n\nSynonyms:\nsheen/named.Builder\nsheen/named Builder","url":"sheen/named.html#Builder"},{"doc":"sheen/named","title":"display","content":"pub fn display(\n  builder: Builder(a),\n  display: String,\n) -&gt; Builder(a)\n\nSynonyms:\nsheen/named.display\nsheen/named display","url":"sheen/named.html#display"},{"doc":"sheen/named","title":"enum","content":"pub fn enum(\n  builder: Builder(String),\n  values: List(#(String, a)),\n) -&gt; Builder(a)\n\nSynonyms:\nsheen/named.enum\nsheen/named enum","url":"sheen/named.html#enum"},{"doc":"sheen/named","title":"help","content":"pub fn help(builder: Builder(a), help: String) -&gt; Builder(a)\n\nSynonyms:\nsheen/named.help\nsheen/named help","url":"sheen/named.html#help"},{"doc":"sheen/named","title":"integer","content":"pub fn integer(builder: Builder(String)) -&gt; Builder(Int)\n\nSynonyms:\nsheen/named.integer\nsheen/named integer","url":"sheen/named.html#integer"},{"doc":"sheen/named","title":"long","content":"pub fn long(builder: Builder(a), long: String) -&gt; Builder(a)\n\nSynonyms:\nsheen/named.long\nsheen/named long","url":"sheen/named.html#long"},{"doc":"sheen/named","title":"new","content":"pub fn new(name: String) -&gt; Builder(String)\n\nSynonyms:\nsheen/named.new\nsheen/named new","url":"sheen/named.html#new"},{"doc":"sheen/named","title":"optional","content":"pub fn optional(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(Option(a)) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/named.optional\nsheen/named optional","url":"sheen/named.html#optional"},{"doc":"sheen/named","title":"repeated","content":"pub fn repeated(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(List(a)) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/named.repeated\nsheen/named repeated","url":"sheen/named.html#repeated"},{"doc":"sheen/named","title":"required","content":"pub fn required(\n  builder: Builder(a),\n) -&gt; fn(\n  fn(fn(fn(a) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n      Result(sheen/internal/command_builder.Builder(b), String),\n) -&gt;\n  fn(sheen/internal/command_builder.Builder(Nil)) -&gt;\n    Result(sheen/internal/command_builder.Builder(b), String)\n\nSynonyms:\nsheen/named.required\nsheen/named required","url":"sheen/named.html#required"},{"doc":"sheen/named","title":"short","content":"pub fn short(builder: Builder(a), short: String) -&gt; Builder(a)\n\nSynonyms:\nsheen/named.short\nsheen/named short","url":"sheen/named.html#short"},{"doc":"sheen/named","title":"sheen/named","content":"","url":"sheen/named.html"},{"doc":"sheen/subcommand","title":"Builder","content":"pub type Builder(a) {\n  Builder(name: String, command: cb.Command(a))\n}\n\nBuilder(name: String, command: cb.Command(a))\n\n\nSynonyms:\nsheen/subcommand.Builder\nsheen/subcommand Builder","url":"sheen/subcommand.html#Builder"},{"doc":"sheen/subcommand","title":"new","content":"pub fn new(\n  name: String,\n  command: fn(Builder(Nil)) -&gt; Result(Builder(a), String),\n) -&gt; sheen/subcommand.Builder(a)\n\nSynonyms:\nsheen/subcommand.new\nsheen/subcommand new","url":"sheen/subcommand.html#new"},{"doc":"sheen/subcommand","title":"optional","content":"pub fn optional(\n  name: String,\n  subcommand: fn(Builder(Nil)) -&gt; Result(Builder(a), String),\n  cont: fn(fn(fn(Option(a)) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(Builder(Nil)) -&gt; Result(Builder(b), String),\n) -&gt; fn(Builder(Nil)) -&gt; Result(Builder(b), String)\n\nSynonyms:\nsheen/subcommand.optional\nsheen/subcommand optional","url":"sheen/subcommand.html#optional"},{"doc":"sheen/subcommand","title":"required","content":"pub fn required(\n  commands: List(\n    #(String, fn(Builder(Nil)) -&gt; Result(Builder(a), String)),\n  ),\n  cont: fn(fn(fn(a) -&gt; Decoder(b)) -&gt; Decoder(b)) -&gt;\n    fn(Builder(Nil)) -&gt; Result(Builder(b), String),\n) -&gt; fn(Builder(Nil)) -&gt; Result(Builder(b), String)\n\nSynonyms:\nsheen/subcommand.required\nsheen/subcommand required","url":"sheen/subcommand.html#required"},{"doc":"sheen/subcommand","title":"sheen/subcommand","content":"","url":"sheen/subcommand.html"}]);